==> openshift-model-config-6.3.0-sources.jar: io/fabric8/openshift/api/model/config/v1/OpenIDClaimsFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface OpenIDClaimsFluent<A extends OpenIDClaimsFluent<A>> extends Fluent<A>{
  public A addToEmail(Integer index,String item);
  public A setToEmail(Integer index,String item);
  public A addToEmail(java.lang.String... items);
  public A addAllToEmail(Collection<String> items);
  public A removeFromEmail(java.lang.String... items);
  public A removeAllFromEmail(Collection<String> items);
  public List<String> getEmail();
  public String getEmail(Integer index);
  public String getFirstEmail();
  public String getLastEmail();
  public String getMatchingEmail(Predicate<String> predicate);
  public Boolean hasMatchingEmail(Predicate<String> predicate);
  public A withEmail(List<String> email);
  public A withEmail(java.lang.String... email);
  public Boolean hasEmail();
  public A addToGroups(Integer index,String item);
  public A setToGroups(Integer index,String item);
  public A addToGroups(java.lang.String... items);
  public A addAllToGroups(Collection<String> items);
  public A removeFromGroups(java.lang.String... items);
  public A removeAllFromGroups(Collection<String> items);
  public List<String> getGroups();
  public String getGroup(Integer index);
  public String getFirstGroup();
  public String getLastGroup();
  public String getMatchingGroup(Predicate<String> predicate);
  public Boolean hasMatchingGroup(Predicate<String> predicate);
  public A withGroups(List<String> groups);
  public A withGroups(java.lang.String... groups);
  public Boolean hasGroups();
  public A addToName(Integer index,String item);
  public A setToName(Integer index,String item);
  public A addToName(java.lang.String... items);
  public A addAllToName(Collection<String> items);
  public A removeFromName(java.lang.String... items);
  public A removeAllFromName(Collection<String> items);
  public List<String> getName();
  public String getName(Integer index);
  public String getFirstName();
  public String getLastName();
  public String getMatchingName(Predicate<String> predicate);
  public Boolean hasMatchingName(Predicate<String> predicate);
  public A withName(List<String> name);
  public A withName(java.lang.String... name);
  public Boolean hasName();
  public A addToPreferredUsername(Integer index,String item);
  public A setToPreferredUsername(Integer index,String item);
  public A addToPreferredUsername(java.lang.String... items);
  public A addAllToPreferredUsername(Collection<String> items);
  public A removeFromPreferredUsername(java.lang.String... items);
  public A removeAllFromPreferredUsername(Collection<String> items);
  public List<String> getPreferredUsername();
  public String getPreferredUsername(Integer index);
  public String getFirstPreferredUsername();
  public String getLastPreferredUsername();
  public String getMatchingPreferredUsername(Predicate<String> predicate);
  public Boolean hasMatchingPreferredUsername(Predicate<String> predicate);
  public A withPreferredUsername(List<String> preferredUsername);
  public A withPreferredUsername(java.lang.String... preferredUsername);
  public Boolean hasPreferredUsername();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  
}

==> openshift-model-config-6.7.2-sources.jar: io/fabric8/openshift/api/model/config/v1/OpenIDClaimsFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface OpenIDClaimsFluent<A extends OpenIDClaimsFluent<A>> extends Fluent<A>{
  public A addToEmail(int index,String item);
  public A setToEmail(int index,String item);
  public A addToEmail(java.lang.String... items);
  public A addAllToEmail(Collection<String> items);
  public A removeFromEmail(java.lang.String... items);
  public A removeAllFromEmail(Collection<String> items);
  public List<String> getEmail();
  public String getEmail(int index);
  public String getFirstEmail();
  public String getLastEmail();
  public String getMatchingEmail(Predicate<String> predicate);
  public Boolean hasMatchingEmail(Predicate<String> predicate);
  public A withEmail(List<String> email);
  public A withEmail(java.lang.String... email);
  public Boolean hasEmail();
  public A addToGroups(int index,String item);
  public A setToGroups(int index,String item);
  public A addToGroups(java.lang.String... items);
  public A addAllToGroups(Collection<String> items);
  public A removeFromGroups(java.lang.String... items);
  public A removeAllFromGroups(Collection<String> items);
  public List<String> getGroups();
  public String getGroup(int index);
  public String getFirstGroup();
  public String getLastGroup();
  public String getMatchingGroup(Predicate<String> predicate);
  public Boolean hasMatchingGroup(Predicate<String> predicate);
  public A withGroups(List<String> groups);
  public A withGroups(java.lang.String... groups);
  public Boolean hasGroups();
  public A addToName(int index,String item);
  public A setToName(int index,String item);
  public A addToName(java.lang.String... items);
  public A addAllToName(Collection<String> items);
  public A removeFromName(java.lang.String... items);
  public A removeAllFromName(Collection<String> items);
  public List<String> getName();
  public String getName(int index);
  public String getFirstName();
  public String getLastName();
  public String getMatchingName(Predicate<String> predicate);
  public Boolean hasMatchingName(Predicate<String> predicate);
  public A withName(List<String> name);
  public A withName(java.lang.String... name);
  public Boolean hasName();
  public A addToPreferredUsername(int index,String item);
  public A setToPreferredUsername(int index,String item);
  public A addToPreferredUsername(java.lang.String... items);
  public A addAllToPreferredUsername(Collection<String> items);
  public A removeFromPreferredUsername(java.lang.String... items);
  public A removeAllFromPreferredUsername(Collection<String> items);
  public List<String> getPreferredUsername();
  public String getPreferredUsername(int index);
  public String getFirstPreferredUsername();
  public String getLastPreferredUsername();
  public String getMatchingPreferredUsername(Predicate<String> predicate);
  public Boolean hasMatchingPreferredUsername(Predicate<String> predicate);
  public A withPreferredUsername(List<String> preferredUsername);
  public A withPreferredUsername(java.lang.String... preferredUsername);
  public Boolean hasPreferredUsername();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  
}
